@@ -18,7 +18,7 @@ from .jsonify import encode as dumps
 from .secure import handle_security
 from .templating import RendererFactory
 from .routing import lookup_controller, NonCanonicalPath
-from .util import _cfg, encode_if_needed, getargspec
+from .util import _cfg, getargspec
 from .middleware.recursive import ForwardRequestException
 
 if six.PY3:
@@ -399,7 +399,7 @@ class PecanBase(object):
         if argspec[2]:
             for name, value in six.iteritems(all_params):
                 if name not in argspec[0]:
-                    kwargs[encode_if_needed(name)] = value
+                    kwargs[name] = value
 
         return args, varargs, kwargs
 
@@ -480,7 +480,7 @@ class PecanBase(object):
         if not pecan_state['content_type']:
             # attempt to find a best match based on accept headers (if they
             # exist)
-            accept = getattr(req.accept, 'header_value', '*/*')
+            accept = getattr(req.accept, 'header_value', '*/*') or '*/*'
             if accept == '*/*' or (
                     accept.startswith('text/html,') and
                     list(content_types.keys()) in self.SIMPLEST_CONTENT_TYPES):
@@ -686,7 +686,7 @@ class PecanBase(object):
             if isinstance(e, exc.HTTPException):
                 # if the client asked for JSON, do our best to provide it
                 best_match = acceptparse.MIMEAccept(
-                    getattr(req.accept, 'header_value', '*/*')
+                    getattr(req.accept, 'header_value', '*/*') or '*/*'
                 ).best_match(('text/plain', 'text/html', 'application/json'))
                 state.response = e
                 if best_match == 'application/json':
